emitter

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 18, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DeliveryReport

type DeliveryReport struct {
	Record  *repository.OutboxRecord // record related to the delivery
	Error   error                    // error during the delivery if any
	Details string                   // more information about the delivery
}

DeliveryReport contains information about an outbox record delivery report.

type Emitter

type Emitter interface {
	// Emit send the information contained in the outbox record to a message
	// broker in a reliable way.
	Emit(*repository.OutboxRecord, chan *DeliveryReport) error
}

Emitter defines the contract for emitters of outbox records.

Directories

Path Synopsis

Jump to